@@ -182,6 +182,7 @@ do_test migrate-stop_start "Migration in a restarting stack"
 do_test migrate-stop-complex "Migration in a complex stopping stack"
 do_test migrate-start-complex "Migration in a complex starting stack"
 do_test migrate-stop-start-complex "Migration in a complex moving stack"
+do_test migrate-shutdown "Order the post-migration 'stop' before node shutdown"
 
 do_test migrate-1 "Migrate (migrate)"
 do_test migrate-2 "Migrate (stable)"
@@ -215,6 +216,7 @@ do_test group15 "-ve group colocation"
 do_test bug-1573 "Partial stop of a group with two children"
 do_test bug-1718 "Mandatory group ordering - Stop group_FUN"
 do_test bug-lf-2422 "Dependancy on partially active group - stop ocfs:*"
+do_test group-fail "Ensure stop order is preserved for partially active groups"
 
 echo ""
 do_test clone-anon-probe-1 "Probe the correct (anonymous) clone instance for each node"
@@ -282,6 +284,8 @@ do_test unmanaged-master "Ensure role is preserved for unmanaged resources"
 do_test master-unmanaged-monitor "Start the correct monitor operation for unmanaged masters"
 do_test master-demote-2 "Demote does not clear past failure"
 do_test master-move "Move master based on failure of colocated group"   
+do_test master-probed-score "Observe the promotion score of probed resources"
+do_test master_monitor_restart "cl#5072 - Ensure master monitor operation will start after promotion."
 
 echo ""
 do_test history-1 "Correctly parse stateful-1 resource state"
@@ -309,15 +313,15 @@ do_test novell-239079 "Notification priority"
 #do_test notify-2 "Notify - 764"
 
 echo ""
-do_test 594 "OSDL #594"
-do_test 662 "OSDL #662"
-do_test 696 "OSDL #696"
-do_test 726 "OSDL #726"
-do_test 735 "OSDL #735"
-do_test 764 "OSDL #764"
-do_test 797 "OSDL #797"
+do_test 594 "OSDL #594 - Unrunnable actions scheduled in transition"
+do_test 662 "OSDL #662 - Two resources start on one node when incarnation_node_max = 1"
+do_test 696 "OSDL #696 - CRM starts stonith RA without monitor"
+do_test 726 "OSDL #726 - Attempting to schedule rsc_posic041_monitor_5000 _after_ a stop"
+do_test 735 "OSDL #735 - Correctly detect that rsc_hadev1 is stopped on hadev3"
+do_test 764 "OSDL #764 - Missing monitor op for DoFencing:child_DoFencing:1"
+do_test 797 "OSDL #797 - Assert triggered: task_id_i > max_call_id"
 do_test 829 "OSDL #829"
-do_test 994 "OSDL #994"
+do_test 994 "OSDL #994 - Stopping the last resource in a resource group causes the entire group to be restarted"
 do_test 994-2 "OSDL #994 - with a dependant resource"
 do_test 1360 "OSDL #1360 - Clone stickiness"
 do_test 1484 "OSDL #1484 - on_fail=stop"
@@ -343,7 +347,22 @@ do_test bug-lf-2551 "STONITH ordering for stop"
 do_test bug-lf-2606 "Stonith implies demote"
 do_test bug-lf-2474 "Ensure resource op timeout takes precedence over op_defaults"
 do_test bug-suse-707150 "Prevent vm-01 from starting due to colocation/ordering"
-
+do_test bug-5014-A-start-B-start "Verify when A starts B starts using symmetrical=false"
+do_test bug-5014-A-stop-B-started "Verify when A stops B does not stop if it has already started using symmetric=false"
+do_test bug-5014-A-stopped-B-stopped "Verify when A is stopped and B has not started, B does not start before A using symmetric=false"
+do_test bug-5014-CthenAthenB-C-stopped "Verify when C then A is symmetrical=true, A then B is symmetric=false, and C is stopped that nothing starts."
+do_test bug-5014-CLONE-A-start-B-start "Verify when A starts B starts using clone resources with symmetric=false"
+do_test bug-5014-CLONE-A-stop-B-started "Verify when A stops B does not stop if it has already started using clone resources with symmetric=false."
+do_test bug-5014-GROUP-A-start-B-start "Verify when A starts B starts when using group resources with symmetric=false."
+do_test bug-5014-GROUP-A-stopped-B-started "Verify when A stops B does not stop if it has already started using group resources with symmetric=false."
+do_test bug-5014-GROUP-A-stopped-B-stopped "Verify when A is stopped and B has not started, B does not start before A using group resources with symmetric=false."
+do_test bug-5007-masterslave_colocation "Verify use of colocation scores other than INFINITY and -INFINITY work on multi-state resources."
+do_test bug-5038 "Prevent restart of anonymous clones when clone-max decreases"
+do_test monitor-onfail-restart "bug-5058 - Monitor failure with on-fail set to restart"
+do_test monitor-onfail-stop    "bug-5058 - Monitor failure wiht on-fail set to stop"
+do_test bug-5059 "No need to restart p_stateful1:*"
+do_test bug-5069-op-enabled  "Test on-fail=ignore with failure when monitor is enabled."
+do_test bug-5069-op-disabled "Test on-fail-ignore with failure when monitor is disabled."
 
 echo ""
 do_test systemhealth1  "System Health ()               #1"
